unit UnidadProcedimientos;

interface
  uses inifiles, sysutils, ShlObj, ActiveX, Windows, ShellCtrls,
      controls, classes, registry, db, dialogs, forms, variants, IdSMTP,
      IdMessage, dateutils, shellapi;

  function leBoolINI (clave, cadena : string; defecto : boolean) : boolean;
  function leCadINI (clave, cadena : string; defecto : String) : String;
  function leNumINI (clave, cadena : string; defecto : Integer) : Integer;
  procedure esCadINI (clave, cadena : string; valor : String);
  procedure esBoolINI (clave, cadena : string; valor : Boolean);
  procedure esNumINI (clave, cadena : string; valor : Integer);
  function SeleccionarCarpeta (titulo : string) : string;
  function encriptar(aStr: String; aKey: Integer): String;
  function desencriptar(aStr: String; aKey: Integer): String;
  function obtenerCadenaRegistro (claveInicial : Cardinal; clave : string; valor : string) : string;
  function ConectarServidorEmail (servidor : string; usuario : string; puerto : integer) : boolean;
  function enviarEmail (servidor : string; usuario : string; contrasena : string;
      puerto : integer; asunto : string; mensaje : TStringList; conAutenticacion : boolean;
      emisor : string; nombreEmisor : string; destinatario : string; cc : string) : boolean;
  function tamanoFichero (sFileToExamine: string) : Integer;


implementation


var
  compEnvioEmail : TIdSMTP;


function tamanoFichero (sFileToExamine: string) : Integer;
var
  SearchRec: TSearchRec;
  sgPath: string;
  inRetval, I1: Integer;
begin
  sgPath := ExpandFileName(sFileToExamine);
  try
    inRetval := FindFirst(ExpandFileName(sFileToExamine), faAnyFile, SearchRec);
    if inRetval = 0 then
      I1 := SearchRec.Size
    else
      I1 := -1;
  finally
    SysUtils.FindClose(SearchRec);
  end;
  Result := I1;
end;



//Funcin para conectar con el servidor de email
function ConectarServidorEmail (servidor : string; usuario : string; puerto : integer) : boolean;
begin
  compEnvioEmail := TIdSMTP.Create(nil);
  compEnvioEmail.host := servidor;
  compEnvioEmail.userid := usuario;
  compEnvioEmail.Port := puerto;
  try
    compEnvioEmail.connect;
    ConectarServidorEmail := true;
  except
    compEnvioEmail.Free;
    raise;
  end;
end;

//enviar email
function enviarEmail (servidor : string; usuario : string; contrasena : string;
    puerto : integer; asunto : string; mensaje : TStringList; conAutenticacion : boolean;
    emisor : string; nombreEmisor : string; destinatario : string; cc : string) : boolean;
var
  compMensaje : TIdMessage;
  envioCorrecto : boolean;
begin
  if conAutenticacion then
  begin
    compEnvioEmail.AuthenticationType := atLogin;
    compEnvioEmail.UserId := usuario;
    compEnvioEmail.Password := contrasena;
  end
  else
    compEnvioEmail.AuthenticationType := atNone;
  compMensaje := TIdMessage.Create (nil);
  compMensaje.From.Address := emisor;
  compMensaje.From.Name := nombreEmisor;
  compMensaje.Recipients.Add.Address := destinatario;
  compMensaje.CCList.Add.Address := cc;
  compMensaje.Body.AddStrings (mensaje);
  compMensaje.Subject := asunto;
  compMensaje.ReplyTo.Add.Address := emisor;
  envioCorrecto := true;
  try
    compEnvioEmail.Send(compMensaje);
  except
    raise;
  end;
  compMensaje.Free;
  enviarEmail := envioCorrecto;
end;




function SeleccionarCarpeta (titulo : string) : string;
var
  Inf: TBrowseInfo;
  Identificador: PItemIDList;
  Gestor : IMalloc;
  Carpeta : Array[0..MAX_PATH] Of Char;
 // handle : THandle;
begin
  With Inf Do
  Begin
    //hwndOwner := Handle;
    pidlRoot := Nil;
    pszDisplayName := Carpeta;
    lpszTitle := pchar(titulo);
    ulFlags := BIF_BROWSEINCLUDEFILES;
    lpfn := Nil;
  End;
  Identificador := SHBrowseForFolder(Inf);
  If Identificador <> Nil Then
  Begin
    SHGetPathFromIDList(Identificador, Carpeta);
    SHGetMalloc(Gestor);
    Gestor.Free(Identificador);
    SeleccionarCarpeta := Carpeta
  end;
end;


//lee un valor booleano de un fichero INI
function leBoolINI (clave, cadena : string; defecto : boolean) : boolean;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := readbool (clave, cadena, defecto);
  finally
    free;
  end;
end;

//lee un valor numrico de un fichero INI
function leNumINI (clave, cadena : string; defecto : Integer) : Integer;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := ReadInteger (clave, cadena, defecto);
  finally
    free;
  end;
end;

//lee un valor string de un fichero INI
function leCadINI (clave, cadena : string; defecto : String) : String;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := ReadString (clave, cadena, defecto);
  finally
    free;
  end;
end;

//escribe un valor string en un fichero INI
procedure esCadINI (clave, cadena : string; valor : String);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteString (clave, cadena, valor);
  finally
    free;
  end;
end;

//escribe un valor boolean en un fichero INI
procedure esBoolINI (clave, cadena : string; valor : Boolean);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteBool (clave, cadena, valor);
  finally
    free;
  end;
end;

//escribe un valor numrico en un fichero INI
procedure esNumINI (clave, cadena : string; valor : Integer);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteInteger (clave, cadena, valor);
  finally
    free;
  end;
end;


//encriptar datos
function encriptar(aStr: String; aKey: Integer): String;
begin
   Result:='';
   RandSeed:=aKey;
   for aKey:=1 to Length(aStr) do
       Result:=Result+Chr(Byte(aStr[aKey]) xor random(256));
end;

//desencriptar datos
function desencriptar(aStr: String; aKey: Integer): String;
begin
   Result := '';
   RandSeed := aKey;
   for aKey := 1 to Length(aStr) do
       Result := Result + Chr(Byte(aStr[aKey]) xor random(256));
end;



function obtenerCadenaRegistro (claveInicial : Cardinal; clave : string; valor : string) : string;
var
  reg: TRegistry;
begin
  Result := '';
  Reg := TRegistry.Create;
  Reg.RootKey := claveInicial;
  reg.OpenKey(clave, False);
  try
    Result := reg.ReadString(valor);
  finally
    reg.CloseKey;
  end;
end;

end.
