unit UnidadMenuPrincipal;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, MSI_GUI, ExtCtrls, ComCtrls, registry;

type
  TformMenuPrincipal = class(TForm)
    MSystemInfo1: TMSystemInfo;
    txtInfo: TMemo;
    Panel1: TPanel;
    bObtener: TButton;
    bGuardar: TButton;
    bCerrar: TButton;
    dlGuardar: TSaveDialog;
    be: TStatusBar;
    procedure bCerrarClick(Sender: TObject);
    procedure bGuardarClick(Sender: TObject);
    procedure bObtenerClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  formMenuPrincipal: TformMenuPrincipal;

  //Tipo registro para almacenar datos en tiempo de ejecucin
  //para memoria RAM
  type
    TMemoria = record
      RAMTotal : double;
      RAMDisponible : double;
      RAMOcupada : double;
      VirtualTotal : double;
      VirtualDisponible : double;
      VirtualOcupada : double;
    end;

  //para CPU
  type
    TCPU = record
      Frecuencia : double;
      Modelo : String;
      Fabricante : String;
      Numero : double;
    end;

  //para SO
  type
    TSO = record
      VersionCompleta : string;
      VersionMenor : Integer;
      VersionMayor : Integer;
      VersionBuild : Integer;
      Plataforma : string;
      Usuario : string;
      Organizacion : string;
      Directorios : TStringList;
      VariablesEntorno : TStringList;
      ServicePack : string;
      Parches : TStringList;
      TipoProducto : string;
      ClaveProducto : string;
      //SuitesInstaladas : string;
    end;

  //para Monitor/tarjeta video
  type
    TMonitor = record
      TarjetaGraficaNombre : string;
      TarjetaGraficaMemoria : Double;
      TarjetaGraficaChipset : string;
      MonitorResolucion : string;
      MonitorNumeroColores : Double;
      SalvaPantallasActivo : boolean;
    end;

  //para BIOS
  type
    TBIOS = record
      Fecha : string;
      Version : string;
    end;

  //Para IPs tarjetas red
  type
    ipTRed = record
      ip : TStringList;
      mascara : TStringList;
      dhcpIP : TStringList;
      dhcpMascara : TStringList;
      gatewayIP : TStringList;
      gatewayMascara : TStringList;
      mac : string;
      winIP : TStringList;
      winIPMascara : TStringList;
      winSecundariaIP : TStringList;
      winSecundariaMascara : TStringList;
      DHCPActivo : Boolean;
      winActivo : Boolean;
    end;

  //para la RED
  type
    TRED = record
      Tarjeta : string;
      NombrePC : string;
      IP : string;
      MAC : string;
      IPRouter : string;
      Dominio : string;
      ServidorDHCP : string;
      Mascara : string;
      PuertaEnlace : string;
      WINIP1 : string;
      WINIP2 : string;
      DHCPIP : string;
      WINActivo : boolean;
      DHCPActivo : boolean;
      EnrutadoActivo : boolean;
      ProxyActivo : boolean;
      DNSActivo : boolean;
      WinSock : string;
      WinSockVersion : string;
      WinSockEstado : string;
      Protocolos : TStringList;
      Servicios : TStringList;
      DNS : TStringList;
      UnidadesRed : TStringList;
      NumeroTarjetas : integer;
      NumeroTarjetasVirtuales : integer;
      tarjetasVirtuales : TStringList;
      macTarjetasVirtuales : TStringList;
      tarjetasTCPIP : TStringList;
      macTarjetasTCPIP : TStringList;
      IPs : array of ipTRed;
    end;

  //para Inicio
  type
    TInicio = record
      RegeditRun : TStringList;
      WinINI : TStringList;
      SystemINI : TStringList;
      CarpetaInicio : TStringList;
    end;

  //para Programas instalados
  type
    TProgramasInstalados = record
      Nombre : string;
      Version : string;
      Tamano : string;
      RutaDesinstalacion : string;
    end;

   //Para procesos en memoria
   type
     TProcesos = record
       Nombre : string;
       Ruta : string;
     end;

   //Para email y SMTP
   type
     TEMailSMTP = record
       Email : string;
       smtp : string;
       pop3 : string;
     end;

var
  oMemoria : TMemoria;
  oCPU : TCPU;
  oSO : TSO;
  oMonitor : TMonitor;
  oBIOS : TBIOS;
  oRED : TRED;
  oInicio : TInicio;
  oProgramasInstalados: array of TProgramasInstalados;
  oProcesos: array of TProcesos;
  oIPTRed : ipTRed;
  oEMailSMTP : TEMailSMTP;



implementation

uses MSI_OS;


{$R *.dfm}

//Obtiene la memoria RAM (libre, total y ocupada) y la memoria Virtual
//guarda los valores en memoria : TMemoria (declarado arriba)
procedure obtenerMemoria ();
var
  MS : TMemoryStatus;
begin
  try
    GlobalMemoryStatus(MS);
    oMemoria.RAMTotal := MS.dwTotalPhys;
    oMemoria.RAMDisponible := MS.dwAvailPhys;
    oMemoria.RAMOcupada := MS.dwTotalPhys - MS.dwAvailPhys;
    oMemoria.VirtualTotal := MS.dwTotalVirtual;
    oMemoria.VirtualDisponible := MS.dwAvailVirtual;
    oMemoria.VirtualOcupada := MS.dwTotalVirtual - MS.dwAvailVirtual;
  except
  end;
end;

//Nombre de usuario del sistema operativo
function obtenerNombreUsuarioSO : String;
var
  pcUser : PChar;
  dwUSize : DWORD;
begin
  dwUSize := 21;
  GetMem(pcUser, dwUSize);
  try
    if Windows.GetUserName(pcUser, dwUSize) then
      Result := pcUser
  finally
    FreeMem(pcUser);
  end;
end;


//Datos CPU (utilizando componente MSI)
procedure obtenerCPU ();
begin
  try
    with formMenuPrincipal  do
    begin
      MSystemInfo1.CPU.GetInfo;
      oCPU.Frecuencia := MSystemInfo1.CPU.Frequency;
      oCPU.Modelo := MSystemInfo1.CPU.FriendlyName;
      oCPU.Fabricante := MSystemInfo1.CPU.Vendor;
      oCPU.Numero := MSystemInfo1.CPU.Count;
    end;
  finally
    //formMenuPrincipal.free;
  end;
end;

//Datos SO (utilizando componente MSI)
procedure obtenerSO ();
begin
  try
    with formMenuPrincipal do
    begin
      MSystemInfo1.OS.GetInfo;
      oSO.VersionCompleta := IntToStr(MSystemInfo1.OS.MajorVersion) + '.' +
         IntToStr(MSystemInfo1.OS.MinorVersion) + '.' +
         IntToStr(MSystemInfo1.OS.BuildNumber);
      oSO.VersionMenor := MSystemInfo1.OS.MinorVersion;
      oSO.VersionMayor := MSystemInfo1.OS.MajorVersion;
      oSO.VersionBuild := MSystemInfo1.OS.BuildNumber;
      //oSO.Plataforma := Format('%s %s',[OSVersion, MSystemInfo1.OS.CSD]);
      oSO.Usuario := MSystemInfo1.OS.RegisteredUser;
      oSO.Organizacion := MSystemInfo1.OS.RegisteredOrg;
      oSO.Directorios := TStringList.Create;
      oSO.Directorios.AddStrings (MSystemInfo1.OS.Folders);
      oSO.VariablesEntorno := TStringList.Create;
      oSO.VariablesEntorno.AddStrings(MSystemInfo1.OS.Environment);
      OSo.ServicePack :=  inttostr(MSystemInfo1.OS.NTSpecific.ServicePackMajorVersion) +
          '.' + IntToStr(MSystemInfo1.OS.NTSpecific.ServicePackMinorVersion);
      oSO.Parches := TStringList.Create;
      oSO.Parches.AddStrings (MSystemInfo1.OS.NTSpecific.HotFixes);
      oSO.TipoProducto := MSystemInfo1.OS.NTSpecific.GetProductTypeStr(MSystemInfo1.OS.NTSpecific.ProductType);
      oSO.ClaveProducto := MSystemInfo1.OS.NTSpecific.ProductKey;
      //Para futuras versiones
      //MSystemInfo1.OS.NTSpecific.GetInstalledSuitesStr();
    end;
  finally
    //formMenuPrincipal.free;
  end;
end;

//Datos BIOS (utilizando componente MSI)
procedure obtenerBIOS ();
begin
  try
    with formMenuPrincipal do
    begin
      try
        MSystemInfo1.Machine.GetInfo(0);
      except
      end;
      try
        MSystemInfo1.Machine.BIOS.GetInfo;
      except
      end;
      oBIOS.Fecha := MSystemInfo1.Machine.BIOS.Date;
      oBIOS.Version := MSystemInfo1.Machine.BIOS.Copyright;
    end;
  finally
    //formMenuPrincipal.free;
  end;
end;

//Monitor y tarjeta de video (Utilizando componente MSI)
procedure obtenerMonitor ();
    //Nmero de colores
    function obtenerNumeroColores : integer;
    var
      tHDC : hdc;
    begin
      tHDC := GetDC(0);
      Result := GetDeviceCaps(tHDC, 12) * GetDeviceCaps(tHDC, 14);
      ReleaseDC(0, tHDC);
    end;
 var
  SC_Status  : integer;
begin
  try
    with formMenuPrincipal do
    begin
      MSystemInfo1.Display.GetInfo;
      oMonitor.TarjetaGraficaNombre := MSystemInfo1.Display.Adapter;
      oMonitor.MonitorResolucion := inttostr(screen.width) + 'x' +
          inttostr(screen.height);
      oMonitor.MonitorNumeroColores := obtenerNumeroColores;
      oMonitor.TarjetaGraficaChipset := MSystemInfo1.Display.Chipset;
      oMonitor.TarjetaGraficaMemoria := MSystemInfo1.Display.Memory;
      try
        SystemParametersInfo(SPI_GETSCREENSAVEACTIVE, 0, @SC_Status, 0);
      except
      end;
      if SC_Status = 1 then
        oMonitor.SalvaPantallasActivo := true
      else
        oMonitor.SalvaPantallasActivo := false;
    end;
  finally
    //formMenuPrincipal.free;
  end;
end;

//Datos RED (utilizando componente MSI)
procedure obtenerRED ();
    //Lista de unidades de red conectadas al PC
    function obtenerUnidadesRed () : TStrings;
    var
      listaUnidades : TStrings;
      i : char;
      ThePath : string;
      MaxNetPathLen : dword;
    begin
      listaUnidades := TStringList.Create;
      listaUnidades.Clear;
      MaxNetPathLen := MAX_PATH;
      SetLength(ThePath, MAX_PATH);
      for i := 'A' to 'Z' do
      begin
       if WNetGetConnection(PChar('' + I + ':'), PChar(ThePath),
           MaxNetPathLen) <> ERROR_NOT_CONNECTED then
         listaUnidades.Add(I + ': ' + ThePath);
      end;
      Result := listaUnidades;
    end;
var
  lLista : TStringList;
  i : integer;
  regIPs : ipTRed;
begin
  try
    with formMenuPrincipal do
    begin
      MSystemInfo1.Network.GetInfo;
      oRED.NumeroTarjetasVirtuales := MSystemInfo1.Network.VirtualAdapters.Count;
      oRED.tarjetasVirtuales := TStringList.Create;
      for i := 0 to oRED.NumeroTarjetasVirtuales - 1 do
      begin
        oRED.tarjetasVirtuales.Add(MSystemInfo1.Network.VirtualAdapters[i]);
      end;

      oRED.NombrePC := MSystemInfo1.Machine.Name;
      if MSystemInfo1.Network.IPAddresses.Count > 0 then
        oRED.IP := MSystemInfo1.Network.IPAddresses[0];
      if MSystemInfo1.Network.IPAddresses.Count > 1 then
        oRED.IPRouter := MSystemInfo1.Network.IPAddresses.Strings[1];

{      if oRED.NumeroTarjetas > 0 then
      begin
        for i := 0 to oRED.NumeroTarjetas - 1 do
          if oRED.Tarjeta <> '' then
            oRED.Tarjeta := oRed.Tarjeta + ' | ' + MSystemInfo1.Network.PhysicalAdapters[i]
          else
            oRED.Tarjeta := MSystemInfo1.Network.PhysicalAdapters[i];

        if MSystemInfo1.Network.MACAddresses.Count > 0 then
          for i := 0 to MSystemInfo1.Network.MACAddresses.Count - 1 do
            if oRED.MAC <> '' then
              oRED.MAC := oRED.mac + ' | ' + MSystemInfo1.Network.MACAddresses[i]
            else
              oRED.MAC := MSystemInfo1.Network.MACAddresses[i];
      end;                               }


      MSystemInfo1.Network.TCPIP.GetInfo;
      oRED.Dominio := MSystemInfo1.Network.TCPIP.DomainName;
      oRED.ServidorDHCP := MSystemInfo1.Network.TCPIP.DHCPScopeName;
      oRED.DNS := TStringList.Create;
      oRED.DNS.AddStrings(MSystemInfo1.Network.TCPIP.DNSServers);

      oRED.NumeroTarjetas := MSystemInfo1.Network.TCPIP.AdapterCount;
      oRED.tarjetasTCPIP := TStringList.Create;
      oRED.macTarjetasTCPIP := TStringList.Create;
      SetLength (ored.ips, oRED.NumeroTarjetas);
      for i := 0 to oRED.NumeroTarjetas - 1 do
      begin
        oRED.tarjetasTCPIP.Add(MSystemInfo1.Network.TCPIP.Adapter[i].Name);
        regIPs.ip := TStringList.Create;
        regIPs.mascara := TStringList.Create;
        regIPs.dhcpIP := TStringList.Create;
        regIPs.dhcpMascara := TStringList.Create;
        regIPs.ip := MSystemInfo1.Network.TCPIP.Adapter[i].IPAddress;  //mete todas las direcciones ip
        regIPs.mascara := MSystemInfo1.Network.TCPIP.Adapter[i].IPAddressMask;
        regIPs.dhcpIP := MSystemInfo1.Network.TCPIP.Adapter[i].DHCP_IPAddress;
        regIPs.dhcpMascara := MSystemInfo1.Network.TCPIP.Adapter[i].DHCP_IPAddressMask;
        regIPs.mac := MSystemInfo1.Network.TCPIP.Adapter[i].Address;
        regIPs.gatewayIP := MSystemInfo1.Network.TCPIP.Adapter[i].Gateway_IPAddress;
        regIPs.DHCPActivo := MSystemInfo1.Network.TCPIP.Adapter[i].EnableDHCP;
        regIPs.WinActivo := MSystemInfo1.Network.TCPIP.Adapter[i].HaveWINS;
        regIPs.gatewayMascara := MSystemInfo1.Network.TCPIP.Adapter[i].Gateway_IPAddressMask;
        regIPs.winIP := MSystemInfo1.Network.TCPIP.Adapter[i].PrimaryWINS_IPAddress;
        regIPs.winIPMascara := MSystemInfo1.Network.TCPIP.Adapter[i].PrimaryWINS_IPAddressMask;
        regIPs.winSecundariaIP := MSystemInfo1.Network.TCPIP.Adapter[i].SecondaryWINS_IPAddress;
        regIPs.winSecundariaMascara := MSystemInfo1.Network.TCPIP.Adapter[i].SecondaryWINS_IPAddressMask;
        oRED.IPs[i] := regIPs;
      end;

      if MSystemInfo1.Network.TCPIP.AdapterCount > 0 then
      begin
        lLista := TStringList.Create;
        lLista.AddStrings (MSystemInfo1.Network.TCPIP.Adapter[0].IPAddressMask);
        oRED.Mascara := lLista.Strings[0];
        lLista.Clear;
        lLista.AddStrings (MSystemInfo1.Network.TCPIP.Adapter[0].Gateway_IPAddress);
        oRED.PuertaEnlace := lLista.Strings[0];
        lLista.Clear;
        lLista.AddStrings (MSystemInfo1.Network.TCPIP.Adapter[0].PrimaryWINS_IPAddress);
        oRED.WINIP1 := lLista.Strings[0];
        lLista.Clear;
        lLista.AddStrings (MSystemInfo1.Network.TCPIP.Adapter[0].SecondaryWINS_IPAddress);
        oRED.WINIP2 := lLista.Strings[0];
        lLista.Clear;
        lLista.AddStrings (MSystemInfo1.Network.TCPIP.Adapter[0].DHCP_IPAddress);
        oRED.DHCPIP := lLista.Strings[0];
        oRED.WINActivo := MSystemInfo1.Network.TCPIP.Adapter[0].HaveWINS;
        oRED.DHCPActivo := MSystemInfo1.Network.TCPIP.Adapter[0].EnableDHCP;
        oRED.EnrutadoActivo := MSystemInfo1.Network.TCPIP.EnableRouting;
        oRED.ProxyActivo := MSystemInfo1.Network.TCPIP.EnableProxy;
        oRED.DNSActivo := MSystemInfo1.Network.TCPIP.EnableDNS;
      end;
      MSystemInfo1.Network.WinSock.GetInfo;
      oRED.WinSock := MSystemInfo1.Network.WinSock.Description;
      oRED.WinSockVersion :=
          inttostr(MSystemInfo1.Network.WinSock.MajorVersion) + '.' +
          inttostr(MSystemInfo1.Network.WinSock.MinorVersion);
      if MSystemInfo1.Network.WinSock.Status = 'Running' then
        oRED.WinSockEstado := 'Iniciado'
      else
        oRED.WinSockEstado := 'No iniciado';
      oRED.Protocolos := TStringList.Create;
      for i := 0 to MSystemInfo1.Network.Protocols.Count - 1 do
        oRED.Protocolos.Add(MSystemInfo1.Network.Protocols.Strings[i]);
      oRED.Servicios := TStringList.Create;
      oRED.Servicios.AddStrings(MSystemInfo1.Network.Clients);
      oRED.UnidadesRed := TStringList.Create;
      oRED.UnidadesRed.AddStrings(obtenerUnidadesRed);
    end;
  finally
    //formMenuPrincipal.free;
  end;
end;

 //Inicio (utilizando componente MSI)
procedure obtenerInicio ();
var
  i : integer;
begin
  try
    with formMenuPrincipal do
    begin
      MSystemInfo1.Startup.GetInfo;
      //inicio en Regedit
      oInicio.RegeditRun := TStringList.Create;
      for i := 0 to MSystemInfo1.Startup.HKLM_Count - 1 do
        oInicio.RegeditRun.Add(MSystemInfo1.Startup.HKLM_Runs[i]);
      //inicio en Win.ini
      oInicio.WinINI := TStringList.Create;
      for i := 0 to MSystemInfo1.Startup.WinINI_Count - 1 do
        oInicio.WinINI.Add(MSystemInfo1.Startup.WinINI_Runs[i]);
      //inicio en system.ini
      oInicio.SystemINI := TStringList.Create;
      for i := 0 to MSystemInfo1.Startup.SystemINI_Count - 1 do
        oInicio.SystemINI.Add(MSystemInfo1.Startup.SystemINI_Runs[i]);
      //inicio en carpeta Inicio
      oInicio.CarpetaInicio := TStringList.Create;
      for i := 0 to MSystemInfo1.Startup.User_Count - 1 do
        oInicio.CarpetaInicio.Add(MSystemInfo1.Startup.User_Runs[i]);
    end;
  finally
    //formMenuPrincipal.free;
  end;
end;


//Programas instalados (utilizando componente MSI)
procedure obtenerProgramasInstalados ();
var
  i : integer;
begin
  try
    with formMenuPrincipal do
    begin
      MSystemInfo1.Software.GetInfo;
      //asignamos el tamao al array dinmico
      SetLength(oProgramasInstalados, MSystemInfo1.Software.Products.Count);
      for i := 0 to MSystemInfo1.Software.Products.Count - 1 do
      begin
        oProgramasInstalados[i].Nombre := MSystemInfo1.Software.Products[i];
        oProgramasInstalados[i].Version := MSystemInfo1.Software.Versions[i];
        oProgramasInstalados[i].RutaDesinstalacion := MSystemInfo1.Software.Uninstalls[i];
      end;
    end;
  finally
    //formMenuPrincipal.free;
  end;
end;

procedure obtenerProcesosMemoria ();
var
  i : integer;
begin
  try
    with formMenuPrincipal do
    begin
      MSystemInfo1.ProcessList.GetInfo;
      //asignamos el tamao al array dinmico
      SetLength(oProcesos, MSystemInfo1.ProcessList.ProcessCount);
      for i := 0 to MSystemInfo1.ProcessList.ProcessCount - 1 do
      begin
        oProcesos[i].Nombre := MSystemInfo1.ProcessList.Processes[i].Name;
        oProcesos[i].Ruta := MSystemInfo1.ProcessList.Processes[i].ImageName;
      end;
    end;
  finally
  end;
end;

procedure ObtenerEMailSMTP;
var
  Registry: TRegistry;
  AccountStr: string;
begin
  Registry := TRegistry.Create;
  try
    Registry.RootKey := hkey_CURRENT_USER;
    if Registry.OpenKey('software\microsoft\internet account manager', False) then  {}
    begin
      AccountStr := Registry.ReadString('default mail account');
      Registry.CloseKey;
      if (AccountStr <> '') then
        if Registry.OpenKey('software\microsoft\internet account manager\accounts\' +
          AccountStr, False) then  {}
        begin
          oEMailSMTP.smtp  := Registry.ReadString('SMTP Server');
          oEMailSMTP.Email := Registry.ReadString('SMTP Email Address');
          oEMailSMTP.pop3 := Registry.ReadString('POP3 Server');
          Registry.CloseKey;
        end;
    end;
  finally
    Registry.Free;
  end;
end;


procedure TformMenuPrincipal.bCerrarClick(Sender: TObject);
begin
  close;
end;

procedure TformMenuPrincipal.bGuardarClick(Sender: TObject);
begin
  if dlGuardar.Execute then
    txtInfo.Lines.SaveToFile(dlGuardar.FileName);
end;

procedure TformMenuPrincipal.bObtenerClick(Sender: TObject);
var
  parches : string;
  i : integer;
  regIPs : ipTRed;
begin
  //Memoria RAM y Virtual
  be.Panels[0].Text := 'Obteniendo Memoria RAM y memoria Virtual...';
  obtenerMemoria;
         txtInfo.Lines.Add ('[Nombre de usuario]=' + obtenerNombreUsuarioSO);
  txtInfo.Lines.Add ('[Memoria RAM total]=' +  FloatToStr(round(oMemoria.RAMTotal / 1048576)));
  txtInfo.Lines.Add ('[Memoria RAM libre]=' +  FloatToStr(round(oMemoria.RAMDisponible / 1048576)));
  txtInfo.Lines.Add ('[Memoria RAM ocupada]=' +  FloatToStr(round(oMemoria.RAMOcupada / 1048576)));
  txtInfo.Lines.Add ('[Memoria Virtual total]=' +  FloatToStr(round(oMemoria.VirtualTotal / 1048576)));
  txtInfo.Lines.Add ('[Memoria Virtual libre]=' +  FloatToStr(round(oMemoria.VirtualDisponible / 1048576)));
  //Nombre de Usuario del SO
  be.Panels[0].Text := 'Nombre usuario SO...';
  txtInfo.Lines.Add ('[Usuario S.O.]=' + obtenerNombreUsuarioSO);

  //Procesador CPU
  be.Panels[0].Text := 'Procesador...';
  obtenerCPU;
  txtInfo.Lines.Add ('[Procesador - Frecuencia]=' + FloatToStr(oCPU.Frecuencia));
  txtInfo.Lines.Add ('[Procesador - Modelo]=' + oCPU.Modelo);
  txtInfo.Lines.Add ('[Procesador - Fabricante]=' + oCPU.Fabricante);
  txtInfo.Lines.Add ('[Procesador - Nmero]=' + FloatToStr(oCPU.Numero));

  //Sistema Operativo (versin, plataforma, usuario, ...)
  be.Panels[0].Text := 'Sistema Operativo...';
  obtenerSO;
  txtInfo.Lines.Add ('[S.O. Versin]= ' + oSO.VersionCompleta);
  txtInfo.Lines.Add ('[S.O. Plataforma]= ' + oSO.Plataforma);
  txtInfo.Lines.Add ('[S.O. Service Pack]= ' + oSO.ServicePack);
  txtInfo.Lines.Add ('[S.O. Usuario]= ' + oSO.Usuario);
  parches := '';
  for i := 0 to oSO.Parches.Count - 1 do
  begin
   if parches <> '' then
     parches := parches + ' | ' + oSO.Parches.Strings[i]
   else
     parches := oSO.Parches.Strings[i];
  end;
  txtInfo.Lines.Add ('[S.O. Parches]= ' + parches);
  txtInfo.Lines.Add ('[S.O. Tipo]= ' + oSO.TipoProducto);
  txtInfo.Lines.Add ('[S.O. Organizacin]= ' + oSO.Organizacion);
  txtInfo.Lines.Add ('[S.O. Clave]= ' + oSO.ClaveProducto);


   //RED
   be.Panels[0].Text := 'Red...';
   obtenerRED;
   txtInfo.Lines.Add ('[Red nmero tarjetas]= ' + IntToStr(oRED.NumeroTarjetas));
   txtInfo.Lines.Add ('[Red nombre PC]= ' + oRED.NombrePC);
   txtInfo.Lines.Add ('[Red IP Router]= ' + oRED.IPRouter);
   txtInfo.Lines.Add ('[Red Dominio]= ' + oRED.Dominio);
   txtInfo.Lines.Add ('[Red Puerta Enlace]=' + oRED.PuertaEnlace);
   if oRED.EnrutadoActivo then
     txtInfo.Lines.Add ('[Red Enrutado]= S')
   else
     txtInfo.Lines.Add ('[Red Enrutado]= No');
   if oRED.ProxyActivo then
     txtInfo.Lines.Add ('[Proxy activo]= S')
   else
     txtInfo.Lines.Add ('[Proxy activo]= No');
   if oRED.DNSActivo then
     txtInfo.Lines.Add ('[DNS activo]= S')
   else
     txtInfo.Lines.Add ('[DNS activo]= No');

    for i := 0 to oRED.tarjetasTCPIP.count - 1 do
     begin
    {  txtInfo.Lines.Add('[Tarjeta de Red]=' + oRED.tarjetasTCPIP.Strings[i]);
      txtInfo.Lines.Add('[Tarjeta de Red IP]=' + regIPs.ip.Strings[0]);
      txtInfo.Lines.Add('[Tarjeta de Red mscara]=' + regIPs.mascara.Strings[0]);
      txtInfo.Lines.Add('[Tarjeta de Red dhcpIP]=' + regIPs.dhcpIP.Strings[0]);
      txtInfo.Lines.Add('[Tarjeta de Red dhcpMscara]=' + regIPs.dhcpMascara.Strings[0]);
    //  txtInfo.Lines.Add('[Tarjeta de Red mac]=' + regIPs.mac.Strings[i]);
      txtInfo.Lines.Add('[Tarjeta de Red gatewayIP]=' + regIPs.gatewayIP[0]);
   //   txtInfo.Lines.Add('[Tarjeta de Red dhcp activo]=' + regIPs.DHCPActivo.Strings[i]);
    //  txtInfo.Lines.Add('[Tarjeta de Red win activo]=' + regIPs.WinActivo.Strings[i]);
      txtInfo.Lines.Add('[Tarjeta de Red mscara gateway]=' + regIPs.gatewayMascara.Strings[0]);
      txtInfo.Lines.Add('[Tarjeta de Red IP win]=' + regIPs.winIP.Strings[0]);
      txtInfo.Lines.Add('[Tarjeta de Red IP mascara win]=' + regIPs.winIPMascara.Strings[0]);
      txtInfo.Lines.Add('[Tarjeta de Red IP win secundario]=' + regIPs.winSecundariaIP.Strings[0]);
      txtInfo.Lines.Add('[Tarjeta de Red mscara win secundario]=' + regIPs.winSecundariaMascara.Strings[0]);}
     end;
    for i := 0 to oRED.tarjetasVirtuales.count - 1 do
      txtInfo.Lines.Add('[Tarjeta virtual de Red]=' + oRED.tarjetasVirtuales.Strings[i]);
    for i := 0 to oRED.UnidadesRed.Count - 1 do
      txtInfo.Lines.Add ('[Unidad de Red]=' + oRED.UnidadesRed.Strings[i]);


      {oRED.tarjetasTCPIP.Add(MSystemInfo1.Network.TCPIP.Adapter[i].Name);
        regIPs.ip := TStringList.Create;
        regIPs.mascara := TStringList.Create;
        regIPs.dhcpIP := TStringList.Create;
        regIPs.dhcpMascara := TStringList.Create;
        regIPs.ip := MSystemInfo1.Network.TCPIP.Adapter[i].IPAddress;
        regIPs.mascara := MSystemInfo1.Network.TCPIP.Adapter[i].IPAddressMask;
        regIPs.dhcpIP := MSystemInfo1.Network.TCPIP.Adapter[i].DHCP_IPAddress;
        regIPs.dhcpMascara := MSystemInfo1.Network.TCPIP.Adapter[i].DHCP_IPAddressMask;
        regIPs.mac := MSystemInfo1.Network.TCPIP.Adapter[i].Address;
        regIPs.gatewayIP := MSystemInfo1.Network.TCPIP.Adapter[i].Gateway_IPAddress;
        regIPs.DHCPActivo := MSystemInfo1.Network.TCPIP.Adapter[i].EnableDHCP;
        regIPs.WinActivo := MSystemInfo1.Network.TCPIP.Adapter[i].HaveWINS;
        regIPs.gatewayMascara := MSystemInfo1.Network.TCPIP.Adapter[i].Gateway_IPAddressMask;
        regIPs.winIP := MSystemInfo1.Network.TCPIP.Adapter[i].PrimaryWINS_IPAddress;
        regIPs.winIPMascara := MSystemInfo1.Network.TCPIP.Adapter[i].PrimaryWINS_IPAddressMask;
        regIPs.winSecundariaIP := MSystemInfo1.Network.TCPIP.Adapter[i].SecondaryWINS_IPAddress;
        regIPs.winSecundariaMascara := MSystemInfo1.Network.TCPIP.Adapter[i].SecondaryWINS_IPAddressMask;
        oRED.IPs[i] := regIPs;}


    //Inicio
    be.Panels[0].Text := 'Inicio...';
    obtenerInicio;
    for i := 0 to oInicio.RegeditRun.Count - 1 do
      txtInfo.Lines.Add ('[Inicio Regedit]=' + oInicio.RegeditRun.Strings[i]);
    for i := 0 to oInicio.WinINI.Count - 1 do
      txtInfo.Lines.Add ('[Inicio WinINI]=' + oInicio.WinINI.Strings[i]);
    for i := 0 to oInicio.SystemINI.Count - 1 do
      txtInfo.Lines.Add ('[Inicio SystemINI]=' + oInicio.SystemINI.Strings[i]);

    //BIOS
    be.Panels[0].Text := 'BIOS...';
    obtenerBIOS;
    txtInfo.Lines.Add ('[BIOS fecha]=' + oBIOS.Fecha);
    txtInfo.Lines.Add ('[BIOS versin]=' + oBIOS.Version);

    //Monitor
    be.Panels[0].Text := 'Monitor...';
    obtenerMonitor;
    txtInfo.Lines.Add ('[Monitor nombre T.Grfica]=' + oMonitor.TarjetaGraficaNombre);
    txtInfo.Lines.Add ('[Monitor resolucin monitor]=' + oMonitor.MonitorResolucion);
    txtInfo.Lines.Add ('[Monitor nmero colores monitor]=' + FloatToStr(oMonitor.MonitorNumeroColores));
    txtInfo.Lines.Add ('[Monitor chipset T.Grfica]=' + oMonitor.TarjetaGraficaChipset);
    txtInfo.Lines.Add ('[Monitor memoria T.Grfica]=' + FloatToStr(oMonitor.TarjetaGraficaMemoria));

    //Programas instalados
    be.Panels[0].Text := 'Programas instalados...';
    obtenerProgramasInstalados;
    for i := 0 to MSystemInfo1.Software.Products.Count - 1 do
    begin
      txtInfo.Lines.Add ('[Programas intalados nombre]=' + oProgramasInstalados[i].Nombre);
      txtInfo.Lines.Add ('[Programas intalados ruta desinstalacin]=' + oProgramasInstalados[i].RutaDesinstalacion);
      txtInfo.Lines.Add ('[Programas intalados versin]=' + oProgramasInstalados[i].Version);
    end;

    //Procesos en memoria
    be.Panels[0].Text := 'Monitor...';
    obtenerProcesosMemoria;
    for i := 0 to MSystemInfo1.ProcessList.ProcessCount - 1 do
      begin
        txtInfo.Lines.Add ('[Procesos memoria nombre]=' + oProcesos[i].Nombre);
        txtInfo.Lines.Add ('[Procesos memoria ruta]=' + oProcesos[i].Ruta);
      end;

    //Emails
    be.Panels[0].Text := 'Emails...';
    obtenerEmailSMTP;
    txtInfo.Lines.Add ('[SMTP Email]=' + oEMailSMTP.Email);
    txtInfo.Lines.Add ('[SMTP smtp]=' + oEMailSMTP.smtp);
    txtInfo.Lines.Add ('[SMTP pop3]=' + oEMailSMTP.pop3);

  be.Panels[0].Text := 'Proceso finalizado correctamente.';
end;


end.
